# Generated by Django 4.2.25 on 2025-10-28 15:23

# Django
import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("aapayout", "0003_esi_fleet_import"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="fleet",
            name="doctrine",
        ),
        migrations.RemoveField(
            model_name="fleet",
            name="location",
        ),
        migrations.AddField(
            model_name="fleet",
            name="battle_report",
            field=models.URLField(blank=True, help_text="Battle report URL (optional)", max_length=500),
        ),
        migrations.AlterField(
            model_name="fleet",
            name="fleet_time",
            field=models.DateTimeField(default=django.utils.timezone.now, help_text="Fleet operation time"),
        ),
    ]
