{% extends 'aapayout/base.html' %}

{% load i18n %}
{% load humanize %}

{% block details %}
    <div class="card card-primary">
        <div class="card-header">
            <div class="card-title">{% translate "Dashboard" %}</div>
        </div>

        <div class="card-body">
            {{ text }}
        </div>
    </div>
{% endblock %}

{% block extra_javascript %}
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_script %}
{% endblock %}
